@@ -70,10 +70,12 @@ void ContactMatcher::onSetupReady()
 ContactMatcher::~ContactMatcher()
 {
     Q_FOREACH(QContactFetchRequest *request, mRequests.keys()) {
+        request->cancel();
         request->deleteLater();
     }
     mRequests.clear();
     mContactMap.clear();
+    mManager->disconnect(this);
     mManager->deleteLater();
 }
 
